/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.web;

import java.util.ArrayList;
import java.util.List;

import dk.vajhoej.vms.web.api.JsonApiModule;
import dk.vajhoej.vms.web.api.XmlApiModule;
import dk.vajhoej.vms.web.file.FileModule;
import dk.vajhoej.vms.web.help.HelpModule;
import dk.vajhoej.vms.web.http.HttpModule;
import dk.vajhoej.vms.web.https.HttpsModule;

/**
 * Class Server is the main server program.
 */
public class Server {
	private static void run(List<AccessModule> accmod, List<FunctionModule> funcmod, boolean login) {
		for(AccessModule am : accmod) {
			am.run(funcmod, login);
		}
	}
	/**
	 * Main method.
	 * @param args arguments
	 */
	public static void main(String[] args) {
		List<AccessModule> accmod = new ArrayList<AccessModule>();
		List<FunctionModule> funcmod = new ArrayList<FunctionModule>();
		boolean login = false;
		int ix = 0;
		while(ix < args.length) {
			if(args[ix].equalsIgnoreCase("http")) {
				ix++;
				int port = Integer.parseInt(args[ix]);
				ix++;
				accmod.add(new HttpModule(port));
			} else if(args[ix].equalsIgnoreCase("https")) {
				ix++;
				int port = Integer.parseInt(args[ix]);
				ix++;
				String jkspath = args[ix];
				ix++;
				String password = args[ix];
				ix++;
				accmod.add(new HttpsModule(port, jkspath, password));
			} else if(args[ix].equalsIgnoreCase("file")) {
				ix++;
				String dir = args[ix];
				ix++;
				funcmod.add(new FileModule(dir));
			} else if(args[ix].equalsIgnoreCase("help")) {
				ix++;
				funcmod.add(new HelpModule());
			} else if(args[ix].equalsIgnoreCase("xmlapi")) {
				ix++;
				funcmod.add(new XmlApiModule());
			} else if(args[ix].equalsIgnoreCase("jsonapi")) {
				ix++;
				funcmod.add(new JsonApiModule());
			} else if(args[ix].equalsIgnoreCase("login")) {
				ix++;
				login = true;
			}
		}
		run(accmod, funcmod, login);
	}
}
