/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.web.http;

import java.security.Principal;

import javax.security.auth.Subject;

import org.eclipse.jetty.security.DefaultIdentityService;
import org.eclipse.jetty.security.IdentityService;
import org.eclipse.jetty.security.LoginService;
import org.eclipse.jetty.server.UserIdentity;

import dk.vajhoej.vms.web.Util;

/**
 * Class VmsLoginService is a Jetty LoginService for VMS login.
 */
public class VmsLoginService implements LoginService {
	/**
	 * Class VmsUser represents a VMS user.
	 */
	public static class VmsUser implements UserIdentity, Principal {
		private String usrnam;
		private boolean valid;
		/**
		 * Create valid instance.
		 * @param usrnam username
		 */
		public VmsUser(String usrnam) {
			this.usrnam = usrnam;
			this.valid = true;
		}
		public Subject getSubject() {
			return null;
		}
		public Principal getUserPrincipal() {
			return this;
		}
		public boolean isUserInRole(String role, Scope scope) {
			return role.equals("user");
		}
		public String getName() {
			return usrnam;
		}
		/**
		 * Check valid status.
		 * @return if valid
		 */
		public boolean isValid() {
			return valid;
		}
		/**
		 * Set valid status.
		 * @param valid new valid status
		 */
		public void setValid(boolean valid) {
			this.valid = valid;
		}
	}
	private IdentityService idsvc = new DefaultIdentityService();
	public IdentityService getIdentityService() {
		return idsvc;
	}
	public String getName() {
		return "VMS";
	}
	public UserIdentity login(String username, Object credentials) {
		try {
			return Util.checkCredentials(username, (String)credentials) ? new VmsUser(username) : null;
		} catch (Exception e) {
			return null;
		}
	}
	public void logout(UserIdentity user) {
		((VmsUser)user).setValid(false);
	}
	public void setIdentityService(IdentityService service) {
		idsvc = service;
	}
	public boolean validate(UserIdentity user) {
		return ((VmsUser)user).isValid();
	}
}
